@@ -1,5 +1,5 @@
 // Copyright Contributors to the OpenVDB Project
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: Apache-2.0
 
 /// @file openvdb/version.h
 /// @brief Library and file format version numbers
@@ -56,9 +56,9 @@
 ///@{
 /// @brief Library major, minor and patch version numbers
 /// @hideinitializer
-#define OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER 10
+#define OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER 12
 /// @hideinitializer
-#define OPENVDB_LIBRARY_MINOR_VERSION_NUMBER 1
+#define OPENVDB_LIBRARY_MINOR_VERSION_NUMBER 0
 /// @hideinitializer
 #define OPENVDB_LIBRARY_PATCH_VERSION_NUMBER 0
 ///@}
@@ -71,7 +71,7 @@
 #ifndef OPENVDB_ABI_VERSION_NUMBER
 /// @brief The ABI version that OpenVDB was built with
 /// @hideinitializer
-#define OPENVDB_ABI_VERSION_NUMBER 10
+#define OPENVDB_ABI_VERSION_NUMBER 12
 #endif
 
 /// @brief Library version number string of the form "<major>.<minor>.<patch>"
@@ -79,18 +79,18 @@
 /// want the compile-time version number, not the runtime version number
 /// (although the two are usually the same).
 /// @hideinitializer
-#define OPENVDB_LIBRARY_VERSION_STRING "10.1.0"
+#define OPENVDB_LIBRARY_VERSION_STRING "12.0.0"
 
 /// @brief Library version number string of the form "<major>.<minor>.<patch>abi<abi>"
 /// @details This is a macro rather than a static constant because we typically
 /// want the compile-time version number, not the runtime version number
 /// (although the two are usually the same).
 /// @hideinitializer
-#define OPENVDB_LIBRARY_ABI_VERSION_STRING "10.1.0abi10"
+#define OPENVDB_LIBRARY_ABI_VERSION_STRING "12.0.0abi12"
 
 /// @brief Library version number as a packed integer ("%02x%02x%04x", major, minor, patch)
 /// @hideinitializer
-#define OPENVDB_LIBRARY_VERSION_NUMBER 167837696
+#define OPENVDB_LIBRARY_VERSION_NUMBER 201326592
 
 /// @brief Where this version was compiled from if it comes from a
 /// git repo.
@@ -116,16 +116,16 @@
 ///
 /// where X, Y and N are the major, minor and ABI version numbers, respectively.
 #if OPENVDB_ABI_VERSION_NUMBER == OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER
-    #define OPENVDB_VERSION_NAME v10_1
+    #define OPENVDB_VERSION_NAME v12_0
 #else
-    #define OPENVDB_VERSION_NAME v10_1abi10
+    #define OPENVDB_VERSION_NAME v12_0abi12
 #endif
 
 /* Denotes whether VDB was built with IMath Half support */
 #ifndef OPENVDB_USE_IMATH_HALF
-/* #undef OPENVDB_USE_IMATH_HALF */
+#define OPENVDB_USE_IMATH_HALF
 /* Denotes whether VDB was built against Imath 3+ */
-/* #undef OPENVDB_IMATH_VERSION */
+#define OPENVDB_IMATH_VERSION
 #endif
 
 /* Denotes whether VDB was built with Blosc support */
@@ -143,6 +143,11 @@
 #define OPENVDB_USE_DELAYED_LOADING
 #endif
 
+/* Denotes whether VDB was built asserts enabled in VDB code */
+#ifndef OPENVDB_ENABLE_ASSERTS
+/* #undef OPENVDB_ENABLE_ASSERTS */
+#endif
+
 /* Denotes whether VDB was built with explicit template instantiation */
 #ifndef OPENVDB_USE_EXPLICIT_INSTANTIATION
 #define OPENVDB_USE_EXPLICIT_INSTANTIATION
@@ -187,6 +192,7 @@
     OPENVDB_INSTANTIATE Function(Vec3DTree); \
     OPENVDB_INSTANTIATE Function(Vec3ITree);
 
+
 ///////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -196,10 +202,10 @@
     // This can be suppressed by defining OPENVDB_USE_FUTURE_ABI_<VERSION>=ON.
     // Note that, whilst the VDB CMake does not allow this option to be hit,
     // it exists to propagate this message to downstream targets
-    #if OPENVDB_ABI_VERSION_NUMBER == 11
-        #ifndef OPENVDB_USE_FUTURE_ABI_11
-            PRAGMA(message("NOTE: ABI = 11 is still in active development and has not been finalized, "
-                "define OPENVDB_USE_FUTURE_ABI_11 to suppress this message"))
+    #if OPENVDB_ABI_VERSION_NUMBER == 13
+        #ifndef OPENVDB_USE_FUTURE_ABI_13
+            PRAGMA(message("NOTE: ABI = 13 is still in active development and has not been finalized, "
+                "define OPENVDB_USE_FUTURE_ABI_13 to suppress this message"))
         #endif
     #else
         #error expected OPENVDB_ABI_VERSION_NUMBER <= OPENVDB_LIBRARY_MAJOR_VERSION_NUMBER
@@ -210,15 +216,15 @@
 // directive. This can be suppressed by defining OPENVDB_USE_DEPRECATED_ABI_<VERSION>.
 // Note that, whilst the VDB CMake does not allow this option to be hit,
 // it exists to propagate this message to downstream targets
-#ifndef OPENVDB_USE_DEPRECATED_ABI_8
-    #if OPENVDB_ABI_VERSION_NUMBER == 8
-        PRAGMA(message("NOTE: ABI = 8 is deprecated, define OPENVDB_USE_DEPRECATED_ABI_7 "
+#ifndef OPENVDB_USE_DEPRECATED_ABI_10
+    #if OPENVDB_ABI_VERSION_NUMBER == 10
+        PRAGMA(message("NOTE: ABI = 10 is deprecated, define OPENVDB_USE_DEPRECATED_ABI_10 "
             "to suppress this message"))
     #endif
 #endif
-#ifndef OPENVDB_USE_DEPRECATED_ABI_9
-    #if OPENVDB_ABI_VERSION_NUMBER == 9
-        PRAGMA(message("NOTE: ABI = 9 is deprecated, define OPENVDB_USE_DEPRECATED_ABI_8 "
+#ifndef OPENVDB_USE_DEPRECATED_ABI_11
+    #if OPENVDB_ABI_VERSION_NUMBER == 11
+        PRAGMA(message("NOTE: ABI = 11 is deprecated, define OPENVDB_USE_DEPRECATED_ABI_11 "
             "to suppress this message"))
     #endif
 #endif
